==> lit_ui_kit-1.0.3.tar.gz: lib/src/widgets/calendar/lit_calendar_navigation.dart <==
import 'package:flutter/material.dart';
import 'package:lit_ui_kit/lit_ui_kit.dart';

class LitCalendarNavigation extends StatelessWidget {
  final void Function() decreaseByMonth;
  final void Function() increaseByMonth;
  final void Function() onMonthLabelPress;
  final void Function() onYearLabelPress;
  final String yearLabel;
  final String monthLabel;
  const LitCalendarNavigation({
    Key? key,
    required this.decreaseByMonth,
    required this.increaseByMonth,
    required this.onMonthLabelPress,
    required this.onYearLabelPress,
    required this.yearLabel,
    required this.monthLabel,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 4.0),
      child: LayoutBuilder(builder: (context, constraints) {
        return Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            SizedBox(
              width: constraints.maxWidth / 4,
              //decreaseByMonth
              child: Padding(
                padding:
                    const EdgeInsets.symmetric(vertical: 8.0, horizontal: 16.0),
                child: LitPushedThroughButton(
                  onPressed: decreaseByMonth,
                  child: Icon(
                    LitIcons.chevron_left_solid,
                    size: 16.0,
                    color: LitColors.mediumGrey,
                  ),
                  accentColor: HexColor('#919191'),
                  backgroundColor: HexColor('#eeeeee'),
                ),
              ),
            ),
            SizedBox(
              width: constraints.maxWidth / 4,
              child: LitPlainLabelButton(
                fontSize: 18.0,
                onPressed: onMonthLabelPress,
                label: monthLabel,
              ),
            ),
            SizedBox(
              width: constraints.maxWidth / 4,
              child: LitPlainLabelButton(
                fontSize: 18.0,
                onPressed: onYearLabelPress,
                label: yearLabel,
              ),
            ),
            SizedBox(
              width: constraints.maxWidth / 4,
              //decreaseByMonth
              child: Padding(
                padding:
                    const EdgeInsets.symmetric(vertical: 8.0, horizontal: 16.0),
                child: LitPushedThroughButton(
                  onPressed: increaseByMonth,
                  child: Icon(
                    LitIcons.chevron_right_solid,
                    size: 16.0,
                    color: LitColors.mediumGrey,
                  ),
                  accentColor: HexColor('#919191'),
                  backgroundColor: HexColor('#eeeeee'),
                ),
              ),
            ),
          ],
        );
      }),
    );
  }
}

==> lit_ui_kit-1.3.0.tar.gz: lib/src/widgets/calendar/lit_calendar_navigation.dart <==
import 'package:flutter/material.dart';
import 'package:lit_ui_kit/lit_ui_kit.dart';

class LitCalendarNavigation extends StatelessWidget {
  final void Function() decreaseByMonth;
  final void Function() increaseByMonth;
  final void Function() onMonthLabelPress;
  final void Function() onYearLabelPress;
  final String yearLabel;
  final String monthLabel;
  const LitCalendarNavigation({
    Key? key,
    required this.decreaseByMonth,
    required this.increaseByMonth,
    required this.onMonthLabelPress,
    required this.onYearLabelPress,
    required this.yearLabel,
    required this.monthLabel,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 4.0),
      child: LayoutBuilder(builder: (context, constraints) {
        return Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            SizedBox(
              width: constraints.maxWidth / 4,
              //decreaseByMonth
              child: _MonthNavigatorButton(
                icon: LitIcons.chevron_left_solid,
                onChange: decreaseByMonth,
              ),
            ),
            SizedBox(
              width: constraints.maxWidth / 4,
              child: LitPlainLabelButton(
                fontSize: 16.0,
                onPressed: onMonthLabelPress,
                label: monthLabel,
              ),
            ),
            SizedBox(
              width: constraints.maxWidth / 4,
              child: LitPlainLabelButton(
                fontSize: 16.0,
                onPressed: onYearLabelPress,
                label: yearLabel,
              ),
            ),
            SizedBox(
              width: constraints.maxWidth / 4,
              //decreaseByMonth
              child: _MonthNavigatorButton(
                icon: LitIcons.chevron_right_solid,
                onChange: increaseByMonth,
              ),
            ),
          ],
        );
      }),
    );
  }
}

class _MonthNavigatorButton extends StatelessWidget {
  final IconData icon;
  final void Function() onChange;
  const _MonthNavigatorButton({
    Key? key,
    required this.icon,
    required this.onChange,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return LitPushedThroughButton(
      padding: const EdgeInsets.symmetric(
        vertical: 8.0,
        horizontal: 12.0,
      ),
      onPressed: onChange,
      child: FittedBox(
        fit: BoxFit.scaleDown,
        child: Icon(
          icon,
          size: 14.0,
          color: LitColors.mediumGrey,
        ),
      ),
      accentColor: Color(0xFF919191),
      backgroundColor: Color(0xFFeeeeee),
    );
  }
}
